@@ -20,6 +20,7 @@ from django.utils.translation import gettext as _
 from django.utils.translation import gettext_lazy
 from django.views.generic import FormView, TemplateView, View
 
+from plinth import app as app_module
 from plinth.errors import PlinthError
 from plinth.modules import backups, storage
 
@@ -40,7 +41,7 @@ class IndexView(TemplateView):
     def get_context_data(self, **kwargs):
         """Return additional context for rendering the template."""
         context = super().get_context_data(**kwargs)
-        context['app_info'] = backups.app.info
+        context['app_info'] = app_module.App.get('backups').info
         context['repositories'] = [
             repository.get_view_content() for repository in get_repositories()
         ]
@@ -381,7 +382,7 @@ class VerifySshHostkeyView(SuccessMessageMixin, FormView):
         known_hosts_path.parent.mkdir(parents=True, exist_ok=True)
         known_hosts_path.touch()
 
-        with known_hosts_path.open('a') as known_hosts_file:
+        with known_hosts_path.open('a', encoding='utf-8') as known_hosts_file:
             known_hosts_file.write(ssh_public_key + '\n')
 
     def get(self, *args, **kwargs):
