@@ -16,7 +16,7 @@ from plinth import cfg, menu
 from plinth.daemon import Daemon
 from plinth.modules.backups.components import BackupRestore
 from plinth.modules.firewall.components import Firewall
-from plinth.package import Packages
+from plinth.package import Packages, install
 from plinth.utils import format_lazy
 
 from . import manifest
@@ -58,8 +58,6 @@ listen-on-v6 { any; };
 };
 '''
 
-app = None
-
 
 class BindApp(app_module.App):
     """FreedomBox app for Bind."""
@@ -75,7 +73,7 @@ class BindApp(app_module.App):
         info = app_module.Info(app_id=self.app_id, version=self._version,
                                name=_('BIND'), icon='fa-globe-w',
                                short_description=_('Domain Name Server'),
-                               description=_description)
+                               description=_description, manual_page='Bind')
         self.add(info)
 
         menu_item = menu.Menu('menu-bind', info.name, info.short_description,
@@ -99,25 +97,23 @@ class BindApp(app_module.App):
                                        **manifest.backup)
         self.add(backup_restore)
 
+    def setup(self, old_version):
+        """Install and configure the app."""
+        super().setup(old_version)
+        actions.superuser_run('bind',
+                              ['setup', '--old-version',
+                               str(old_version)])
+        self.enable()
 
-def setup(helper, old_version=None):
-    """Install and configure the module."""
-    app.setup(old_version)
-    helper.call(
-        'post', actions.superuser_run, 'bind',
-        ['setup', '--old-version', str(old_version)])
-    helper.call('post', app.enable)
-
-
-def force_upgrade(helper, _packages):
-    """Force upgrade the managed packages to resolve conffile prompt."""
-    helper.install(['bind9'], force_configuration='old')
-    return True
+    def force_upgrade(self, _packages):
+        """Force upgrade the managed packages to resolve conffile prompt."""
+        install(['bind9'], force_configuration='old')
+        return True
 
 
 def get_config():
     """Get current configuration"""
-    data = [line.strip() for line in open(CONFIG_FILE, 'r')]
+    data = [line.strip() for line in open(CONFIG_FILE, 'r', encoding='utf-8')]
 
     forwarders = ''
     dnssec_enabled = False
@@ -141,8 +137,8 @@ def get_config():
 def set_forwarders(forwarders):
     """Set DNS forwarders."""
     flag = 0
-    data = [line.strip() for line in open(CONFIG_FILE, 'r')]
-    conf_file = open(CONFIG_FILE, 'w')
+    data = [line.strip() for line in open(CONFIG_FILE, 'r', encoding='utf-8')]
+    conf_file = open(CONFIG_FILE, 'w', encoding='utf-8')
     for line in data:
         if re.match(r'^\s*forwarders\s+{', line):
             conf_file.write(line + '\n')
@@ -160,10 +156,10 @@ def set_forwarders(forwarders):
 
 def set_dnssec(choice):
     """Enable or disable DNSSEC."""
-    data = [line.strip() for line in open(CONFIG_FILE, 'r')]
+    data = [line.strip() for line in open(CONFIG_FILE, 'r', encoding='utf-8')]
 
     if choice == 'enable':
-        conf_file = open(CONFIG_FILE, 'w')
+        conf_file = open(CONFIG_FILE, 'w', encoding='utf-8')
         for line in data:
             if re.match(r'//\s*dnssec-enable\s+yes;', line):
                 line = line.lstrip('/')
@@ -171,7 +167,7 @@ def set_dnssec(choice):
         conf_file.close()
 
     if choice == 'disable':
-        conf_file = open(CONFIG_FILE, 'w')
+        conf_file = open(CONFIG_FILE, 'w', encoding='utf-8')
         for line in data:
             if re.match(r'^\s*dnssec-enable\s+yes;', line):
                 line = '//' + line
