@@ -13,6 +13,7 @@ from plinth.modules import config
 from plinth.signals import (domain_added, domain_removed, post_hostname_change,
                             pre_hostname_change)
 
+from . import privileged
 from .forms import ConfigurationForm
 
 LOGGER = logging.getLogger(__name__)
@@ -30,6 +31,7 @@ class ConfigAppView(views.AppView):
             'domainname': config.get_domainname(),
             'homepage': config.get_home_page(),
             'advanced_mode': config.get_advanced_mode(),
+            'logging_mode': privileged.get_logging_mode(),
         }
 
     def form_valid(self, form):
@@ -37,6 +39,8 @@ class ConfigAppView(views.AppView):
         old_status = form.initial
         new_status = form.cleaned_data
 
+        is_changed = False
+
         if old_status['hostname'] != new_status['hostname']:
             try:
                 set_hostname(new_status['hostname'])
@@ -87,6 +91,13 @@ class ConfigAppView(views.AppView):
                     messages.success(self.request,
                                      _('Hiding advanced apps and features'))
 
+        if old_status['logging_mode'] != new_status['logging_mode']:
+            privileged.set_logging_mode(new_status['logging_mode'])
+            is_changed = True
+
+        if is_changed:
+            messages.success(self.request, _('Configuration updated'))
+
         return super(views.AppView, self).form_valid(form)
 
 
