@@ -45,8 +45,6 @@ _description = [
       'target=\'_blank\'>freedns.afraid.org</a>.'),
 ]
 
-app = None
-
 
 class DynamicDNSApp(app_module.App):
     """FreedomBox app for Dynamic DNS."""
@@ -98,24 +96,23 @@ class DynamicDNSApp(app_module.App):
         interval = 180 if cfg.develop else 300
         glib.schedule(interval, update_dns)
 
+    def setup(self, old_version):
+        """Install and configure the app."""
+        super().setup(old_version)
+        if not old_version:
+            self.enable()
 
-def setup(helper, old_version=None):
-    """Install and configure the module."""
-    app.setup(old_version)
-    if not old_version:
-        helper.call('post', app.enable)
+        if old_version == 1:
+            config = actions.superuser_run('dynamicdns', ['export-config'])
+            config = json.loads(config)
+            if config['enabled']:
+                self.enable()
+            else:
+                self.disable()
 
-    if old_version == 1:
-        config = actions.superuser_run('dynamicdns', ['export-config'])
-        config = json.loads(config)
-        if config['enabled']:
-            app.enable()
-        else:
-            app.disable()
-
-        del config['enabled']
-        set_config(config)
-        actions.superuser_run('dynamicdns', ['clean'])
+            del config['enabled']
+            set_config(config)
+            actions.superuser_run('dynamicdns', ['clean'])
 
 
 def _query_external_address(domain):
@@ -222,6 +219,7 @@ def _update_dns_for_domain(domain):
 def update_dns(_data):
     """For all configured domains, check and up to date DNS records."""
     config = get_config()
+    app = app_module.App.get('dynamicdns')
     if not app.is_enabled():
         return
 
@@ -258,7 +256,18 @@ def get_config():
     """Return the current configuration."""
     default_config = {'domains': {}}
     config = kvstore.get_default('dynamicdns_config', '{}')
-    return json.loads(config) or default_config
+    config = json.loads(config) or default_config
+    return _fix_corrupt_config(config)
+
+
+def _fix_corrupt_config(config):
+    """Fix malformed configuration result of bug in older version."""
+    if 'null' not in config['domains']:
+        return config
+
+    del config['domains']['null']
+    set_config(config)
+    return config
 
 
 def set_config(config):
