@@ -46,8 +46,6 @@ _description = [
 
 logger = logging.getLogger(__name__)
 
-app = None
-
 
 class EjabberdApp(app_module.App):
     """FreedomBox app for ejabberd."""
@@ -75,7 +73,7 @@ class EjabberdApp(app_module.App):
         shortcut = frontpage.Shortcut(
             'shortcut-ejabberd', info.name,
             short_description=info.short_description, icon=info.icon_filename,
-            description=info.description,
+            description=info.description, manual_page=info.manual_page,
             configure_url=reverse_lazy('ejabberd:index'), clients=info.clients,
             login_required=True)
         self.add(shortcut)
@@ -128,6 +126,25 @@ class EjabberdApp(app_module.App):
         post_hostname_change.connect(on_post_hostname_change)
         domain_added.connect(on_domain_added)
 
+    def setup(self, old_version):
+        """Install and configure the app."""
+        domainname = config.get_domainname()
+        logger.info('ejabberd service domainname - %s', domainname)
+
+        actions.superuser_run('ejabberd',
+                              ['pre-install', '--domainname', domainname])
+        # XXX: Configure all other domain names
+        super().setup(old_version)
+        self.get_component('letsencrypt-ejabberd').setup_certificates(
+            [domainname])
+        actions.superuser_run('ejabberd',
+                              ['setup', '--domainname', domainname])
+        self.enable()
+
+        # Configure STUN/TURN only if there's a valid TLS domain set for Coturn
+        configuration = self.get_component('turn-ejabberd').get_configuration()
+        update_turn_configuration(configuration, force=True)
+
 
 class EjabberdTurnConsumer(TurnConsumer):
     """Component to manage Coturn configuration for ejabberd."""
@@ -137,49 +154,13 @@ class EjabberdTurnConsumer(TurnConsumer):
         update_turn_configuration(config)
 
 
-def setup(helper, old_version=None):
-    """Install and configure the module."""
-    domainname = config.get_domainname()
-    logger.info('ejabberd service domainname - %s', domainname)
-
-    helper.call('pre', actions.superuser_run, 'ejabberd',
-                ['pre-install', '--domainname', domainname])
-    # XXX: Configure all other domain names
-    app.setup(old_version)
-    helper.call('post',
-                app.get_component('letsencrypt-ejabberd').setup_certificates,
-                [domainname])
-    helper.call('post', actions.superuser_run, 'ejabberd',
-                ['setup', '--domainname', domainname])
-    helper.call('post', app.enable)
-
-    # Configure STUN/TURN only if there's a valid TLS domain set for Coturn
-    configuration = app.get_component('turn-ejabberd').get_configuration()
-    update_turn_configuration(configuration, force=True)
-
-
-def get_domains():
-    """Return the list of domains that ejabberd is interested in.
-
-    XXX: Retrieve the list from ejabberd configuration.
-
-    """
-    if app.needs_setup():
-        return []
-
-    domain_name = config.get_domainname()
-    if domain_name:
-        return [domain_name]
-
-    return []
-
-
 def on_pre_hostname_change(sender, old_hostname, new_hostname, **kwargs):
     """
     Backup ejabberd database before hostname is changed.
     """
     del sender  # Unused
     del kwargs  # Unused
+    app = app_module.App.get('ejabberd')
     if app.needs_setup():
         return
 
@@ -193,6 +174,7 @@ def on_post_hostname_change(sender, old_hostname, new_hostname, **kwargs):
     """Update ejabberd config after hostname change."""
     del sender  # Unused
     del kwargs  # Unused
+    app = app_module.App.get('ejabberd')
     if app.needs_setup():
         return
 
@@ -202,23 +184,47 @@ def on_post_hostname_change(sender, old_hostname, new_hostname, **kwargs):
     ], run_in_background=True)
 
 
+def get_domains():
+    """Return the list of domains configured for ejabberd.
+    """
+    app = app_module.App.get('ejabberd')
+    if app.needs_setup():
+        return []
+
+    output = actions.superuser_run('ejabberd', ['get-domains'])
+    return json.loads(output)
+
+
 def on_domain_added(sender, domain_type, name='', description='',
                     services=None, **kwargs):
     """Update ejabberd config after domain name change."""
+    app = app_module.App.get('ejabberd')
     if not name or app.needs_setup():
         return
 
-    conf = actions.superuser_run('ejabberd', ['get-configuration'])
-    conf = json.loads(conf)
-    if name not in conf['domains']:
+    domains = get_domains()
+    if name not in domains:
         actions.superuser_run('ejabberd', ['add-domain', '--domainname', name])
         app.get_component('letsencrypt-ejabberd').setup_certificates()
 
 
+def set_domains(domains):
+    """Configure ejabberd to have this list of domains."""
+    app = app_module.App.get('ejabberd')
+    if not domains or app.needs_setup():
+        return
+
+    commands = ['set-domains', '--domains']
+    commands.extend(domains)
+    actions.superuser_run('ejabberd', commands)
+    app.get_component('letsencrypt-ejabberd').setup_certificates()
+
+
 def update_turn_configuration(config: TurnConfiguration, managed=True,
                               force=False):
     """Update ejabberd's STUN/TURN server configuration."""
-    if app.needs_setup():
+    app = app_module.App.get('ejabberd')
+    if not force and app.needs_setup():
         return
 
     params = ['configure-turn']
