@@ -34,15 +34,13 @@ _description = [
       '<a href="https://git-scm.com/docs/gittutorial">Git tutorial</a>.')
 ]
 
-app = None
-
 
 class GitwebApp(app_module.App):
     """FreedomBox app for Gitweb."""
 
     app_id = 'gitweb'
 
-    _version = 1
+    _version = 2
 
     def __init__(self):
         """Create components for the app."""
@@ -128,6 +126,12 @@ class GitwebApp(app_module.App):
 
         self.set_shortcut_login_required(True)
 
+    def setup(self, old_version):
+        """Install and configure the app."""
+        super().setup(old_version)
+        actions.superuser_run('gitweb', ['setup'])
+        self.enable()
+
 
 class GitwebWebserverAuth(Webserver):
     """Component to handle Gitweb authentication webserver configuration."""
@@ -154,14 +158,7 @@ class GitwebBackupRestore(BackupRestore):
     def restore_post(self, packet):
         """Update access after restoration of backups."""
         super().restore_post(packet)
-        app.update_service_access()
-
-
-def setup(helper, old_version=None):
-    """Install and configure the module."""
-    app.setup(old_version)
-    helper.call('post', actions.superuser_run, 'gitweb', ['setup'])
-    helper.call('post', app.enable)
+        self.app.update_service_access()
 
 
 def repo_exists(name):
@@ -215,7 +212,7 @@ def get_repo_list():
 
             progress_file = os.path.join(GIT_REPO_PATH, repo, 'clone_progress')
             if os.path.exists(progress_file):
-                with open(progress_file) as file_handle:
+                with open(progress_file, encoding='utf-8') as file_handle:
                     clone_progress = file_handle.read()
                     repo_info['clone_progress'] = clone_progress
 
