@@ -31,8 +31,6 @@ _description = [
         users_url=reverse_lazy('users:index'))
 ]
 
-app = None
-
 
 class IkiwikiApp(app_module.App):
     """FreedomBox app for Ikiwiki."""
@@ -60,7 +58,9 @@ class IkiwikiApp(app_module.App):
 
         packages = Packages('packages-ikiwiki', [
             'ikiwiki', 'libdigest-sha-perl', 'libxml-writer-perl',
-            'xapian-omega', 'libsearch-xapian-perl', 'libimage-magick-perl'
+            'xapian-omega', 'libsearch-xapian-perl', 'libimage-magick-perl',
+            'gcc', 'git', 'librpc-xml-perl', 'libcgi-session-perl',
+            'libcgi-formbuilder-perl', 'libc6-dev'
         ])
         self.add(packages)
 
@@ -110,9 +110,8 @@ class IkiwikiApp(app_module.App):
 
         return sites
 
-
-def setup(helper, old_version=None):
-    """Install and configure the module."""
-    app.setup(old_version)
-    helper.call('post', actions.superuser_run, 'ikiwiki', ['setup'])
-    helper.call('post', app.enable)
+    def setup(self, old_version):
+        """Install and configure the app."""
+        super().setup(old_version)
+        actions.superuser_run('ikiwiki', ['setup'])
+        self.enable()
