@@ -26,8 +26,6 @@ _description = [
         box_name=_(cfg.box_name)),
 ]
 
-app = None
-
 
 class InfinotedApp(app_module.App):
     """FreedomBox app for infinoted."""
@@ -56,7 +54,7 @@ class InfinotedApp(app_module.App):
         shortcut = frontpage.Shortcut(
             'shortcut-infinoted', info.name,
             short_description=info.short_description, icon=info.icon_filename,
-            description=info.description,
+            description=info.description, manual_page=info.manual_page,
             configure_url=reverse_lazy('infinoted:index'),
             clients=info.clients, login_required=False)
         self.add(shortcut)
@@ -76,9 +74,8 @@ class InfinotedApp(app_module.App):
                                        **manifest.backup)
         self.add(backup_restore)
 
-
-def setup(helper, old_version=None):
-    """Install and configure the module."""
-    app.setup(old_version)
-    helper.call('post', actions.superuser_run, 'infinoted', ['setup'])
-    helper.call('post', app.enable)
+    def setup(self, old_version):
+        """Install and configure the app."""
+        super().setup(old_version)
+        actions.superuser_run('infinoted', ['setup'])
+        self.enable()
