@@ -24,8 +24,6 @@ _description = [
 
 logger = logging.getLogger(__name__)
 
-app = None
-
 
 class JSXCApp(app_module.App):
     """FreedomBox app for JSXC."""
@@ -80,8 +78,7 @@ class JSXCApp(app_module.App):
                                        **manifest.backup)
         self.add(backup_restore)
 
-
-def setup(helper, old_version=None):
-    """Install and configure the module."""
-    app.setup(old_version)
-    helper.call('post', app.enable)
+    def setup(self, old_version):
+        """Install and configure the app."""
+        super().setup(old_version)
+        self.enable()
