@@ -42,8 +42,6 @@ LIVE_DIRECTORY = '/etc/letsencrypt/live/'
 CERTIFICATE_CHECK_DELAY = 120
 logger = logging.getLogger(__name__)
 
-app = None
-
 
 class LetsEncryptApp(app_module.App):
     """FreedomBox app for Let's Encrypt."""
@@ -99,13 +97,12 @@ class LetsEncryptApp(app_module.App):
 
         return results
 
-
-def setup(helper, old_version=None):
-    """Install and configure the module."""
-    app.setup(old_version)
-    actions.superuser_run(
-        'letsencrypt',
-        ['setup', '--old-version', str(old_version)])
+    def setup(self, old_version):
+        """Install and configure the app."""
+        super().setup(old_version)
+        actions.superuser_run('letsencrypt',
+                              ['setup', '--old-version',
+                               str(old_version)])
 
 
 def certificate_obtain(domain):
