@@ -9,10 +9,7 @@
 */
 
 # Default logo
-# wgLogos takes precedence over wgLogo.
 $wgLogos = [ '1x' => "$wgResourceBasePath/resources/assets/mediawiki.png" ];
-# TODO wgLogo can be removed from Debian 11
-$wgLogo = "$wgResourceBasePath/resources/assets/mediawiki.png";
 
 # Enable file uploads
 $wgEnableUploads = true;
@@ -45,6 +42,9 @@ $wgDefaultSkin = "timeless";
 # Domain Name
 $wgServer = "https://freedombox.local";
 
+# Site Name
+$wgSitename = "Wiki";
+
 # Enable default extensions
 wfLoadExtension( 'Cite' );
 wfLoadExtension( 'Interwiki' );
