@@ -13,20 +13,21 @@ from plinth.daemon import Daemon
 from plinth.modules.backups.components import BackupRestore
 from plinth.modules.firewall.components import Firewall
 from plinth.modules.users.components import UsersAndGroups
-from plinth.package import Packages
+from plinth.package import Package, Packages
 from plinth.utils import format_lazy
 
 from . import manifest
 
 _mods = [
+    Package('minetest-mod-3d-armor') | Package('minetest-mod-player-3d-armor'),
     'minetest-mod-character-creator', 'minetest-mod-craftguide',
     'minetest-mod-infinite-chest', 'minetest-mod-lucky-block',
     'minetest-mod-maidroid', 'minetest-mod-mesecons',
     'minetest-mod-moreblocks', 'minetest-mod-moreores', 'minetest-mod-nether',
-    'minetest-mod-pipeworks', 'minetest-mod-player-3d-armor',
-    'minetest-mod-protector', 'minetest-mod-quartz', 'minetest-mod-skyblock',
-    'minetest-mod-throwing', 'minetest-mod-unified-inventory',
-    'minetest-mod-unifieddyes', 'minetest-mod-worldedit'
+    'minetest-mod-pipeworks', 'minetest-mod-protector', 'minetest-mod-quartz',
+    'minetest-mod-skyblock', 'minetest-mod-throwing',
+    'minetest-mod-unified-inventory', 'minetest-mod-unifieddyes',
+    'minetest-mod-worldedit'
 ]
 
 _description = [
@@ -41,8 +42,6 @@ _description = [
 CONFIG_FILE = '/etc/minetest/minetest.conf'
 AUG_PATH = '/files' + CONFIG_FILE + '/.anon'
 
-app = None
-
 
 class MinetestApp(app_module.App):
     """FreedomBox app for Minetest."""
@@ -71,7 +70,7 @@ class MinetestApp(app_module.App):
         shortcut = frontpage.Shortcut(
             'shortcut-minetest', info.name,
             short_description=info.short_description, icon=info.icon_filename,
-            description=info.description,
+            description=info.description, manual_page=info.manual_page,
             configure_url=reverse_lazy('minetest:index'), clients=info.clients,
             login_required=False)
         self.add(shortcut)
@@ -96,11 +95,10 @@ class MinetestApp(app_module.App):
                                        **manifest.backup)
         self.add(backup_restore)
 
-
-def setup(helper, old_version=None):
-    """Install and configure the module."""
-    app.setup(old_version)
-    helper.call('post', app.enable)
+    def setup(self, old_version):
+        """Install and configure the app."""
+        super().setup(old_version)
+        self.enable()
 
 
 def load_augeas():
