@@ -12,6 +12,7 @@ from django.utils.translation import gettext_lazy
 from django.views.decorators.http import require_POST
 from django.views.generic.edit import FormView
 
+from plinth import app as app_module
 from plinth import network
 from plinth.modules import first_boot, networks
 
@@ -123,7 +124,7 @@ def index(request):
     return TemplateResponse(
         request, 'networks_configuration.html', {
             'app_id': 'networks',
-            'app_info': networks.app.info,
+            'app_info': app_module.App.get('networks').info,
             'title': _('Network Connections'),
             'has_diagnostics': True,
             'is_enabled': True,
@@ -187,7 +188,8 @@ def show(request, uuid):
             device, connection_status['wireless']['ssid'])
         connection_status['wireless'][
             'mode_string'] = WIRELESS_MODE_STRINGS.get(
-                connection['wireless']['mode'], connection['wireless']['mode'])
+                connection_status['wireless']['mode'],
+                connection_status['wireless']['mode'])
 
     return TemplateResponse(
         request, 'connection_show.html', {
