@@ -31,8 +31,6 @@ _description = [
           'for added security and anonymity.'), box_name=_(cfg.box_name))
 ]
 
-app = None
-
 SERVER_CONFIGURATION_FILE = '/etc/openvpn/server/freedombox.conf'
 
 
@@ -74,6 +72,7 @@ class OpenVPNApp(app_module.App):
             'shortcut-openvpn', info.name,
             short_description=info.short_description, icon=info.icon_filename,
             description=info.description + [download_profile],
+            manual_page=info.manual_page,
             configure_url=reverse_lazy('openvpn:index'), login_required=True,
             allowed_groups=['vpn'])
         self.add(shortcut)
@@ -105,12 +104,11 @@ class OpenVPNApp(app_module.App):
         """
         return super().is_enabled() and is_setup()
 
-
-def setup(helper, old_version=None):
-    """Install and configure the module."""
-    app.setup(old_version)
-    helper.call('post', actions.superuser_run, 'openvpn', ['setup'])
-    helper.call('post', app.enable)
+    def setup(self, old_version):
+        """Install and configure the app."""
+        super().setup(old_version)
+        actions.superuser_run('openvpn', ['setup'])
+        self.enable()
 
 
 def is_setup():
@@ -121,7 +119,8 @@ def is_setup():
 def is_using_ecc():
     """Return whether the service is using ECC."""
     if os.path.exists(SERVER_CONFIGURATION_FILE):
-        with open(SERVER_CONFIGURATION_FILE, 'r') as file_handle:
+        with open(SERVER_CONFIGURATION_FILE, 'r',
+                  encoding='utf-8') as file_handle:
             for line in file_handle:
                 if line.strip() == 'dh none':
                     return True
