@@ -38,8 +38,6 @@ _description = [
       'are available.'),
 ]
 
-app = None
-
 
 class QuasselApp(app_module.App):
     """FreedomBox app for Quassel."""
@@ -67,7 +65,7 @@ class QuasselApp(app_module.App):
         shortcut = frontpage.Shortcut(
             'shortcut-quassel', info.name,
             short_description=info.short_description, icon=info.icon_filename,
-            description=info.description,
+            description=info.description, manual_page=info.manual_page,
             configure_url=reverse_lazy('quassel:index'), clients=info.clients,
             login_required=True)
         self.add(shortcut)
@@ -100,12 +98,11 @@ class QuasselApp(app_module.App):
                                        **manifest.backup)
         self.add(backup_restore)
 
-
-def setup(helper, old_version=None):
-    """Install and configure the module."""
-    app.setup(old_version)
-    helper.call('post', app.enable)
-    app.get_component('letsencrypt-quassel').setup_certificates()
+    def setup(self, old_version):
+        """Install and configure the app."""
+        super().setup(old_version)
+        self.enable()
+        self.get_component('letsencrypt-quassel').setup_certificates()
 
 
 def set_domain(domain):
@@ -118,7 +115,8 @@ def get_domain():
     """Read TLS domain from config file select first available if none."""
     domain = None
     try:
-        with open('/var/lib/quassel/domain-freedombox') as file_handle:
+        with open('/var/lib/quassel/domain-freedombox',
+                  encoding='utf-8') as file_handle:
             domain = file_handle.read().strip()
     except FileNotFoundError:
         pass
