@@ -6,7 +6,9 @@ Django views for Searx.
 from django.contrib import messages
 from django.utils.translation import gettext as _
 
-from plinth import actions, views
+from plinth import actions
+from plinth import app as app_module
+from plinth import views
 from plinth.errors import ActionError
 from plinth.modules import searx
 
@@ -23,7 +25,7 @@ class SearxAppView(views.AppView):
         initial = super().get_initial()
         initial['safe_search'] = searx.get_safe_search_setting()
         initial['public_access'] = searx.is_public_access_enabled() and \
-            searx.app.is_enabled()
+            app_module.App.get('searx').is_enabled()
         return initial
 
     def form_valid(self, form):
