@@ -24,8 +24,6 @@ ACCESS_CONF_SNIPPET = '-:ALL EXCEPT root fbx plinth (admin) (sudo):ALL'
 OLD_ACCESS_CONF_SNIPPET = '-:ALL EXCEPT root fbx (admin) (sudo):ALL'
 ACCESS_CONF_SNIPPETS = [OLD_ACCESS_CONF_SNIPPET, ACCESS_CONF_SNIPPET]
 
-app = None
-
 
 class SecurityApp(app_module.App):
     """FreedomBox app for security."""
@@ -57,20 +55,19 @@ class SecurityApp(app_module.App):
                                        **manifest.backup)
         self.add(backup_restore)
 
+    def setup(self, old_version):
+        """Install and configure the app."""
+        super().setup(old_version)
+        if not old_version:
+            enable_fail2ban()
 
-def setup(helper, old_version=None):
-    """Install the required packages"""
-    app.setup(old_version)
-    if not old_version:
-        enable_fail2ban()
+        actions.superuser_run('service', ['reload', 'fail2ban'])
 
-    actions.superuser_run('service', ['reload', 'fail2ban'])
-
-    # Migrate to new config file.
-    enabled = get_restricted_access_enabled()
-    set_restricted_access(False)
-    if enabled:
-        set_restricted_access(True)
+        # Migrate to new config file.
+        enabled = get_restricted_access_enabled()
+        set_restricted_access(False)
+        if enabled:
+            set_restricted_access(True)
 
 
 def enable_fail2ban():
@@ -80,13 +77,13 @@ def enable_fail2ban():
 
 def get_restricted_access_enabled():
     """Return whether restricted access is enabled"""
-    with open(ACCESS_CONF_FILE_OLD, 'r') as conffile:
+    with open(ACCESS_CONF_FILE_OLD, 'r', encoding='utf-8') as conffile:
         if any(line.strip() in ACCESS_CONF_SNIPPETS
                for line in conffile.readlines()):
             return True
 
     try:
-        with open(ACCESS_CONF_FILE, 'r') as conffile:
+        with open(ACCESS_CONF_FILE, 'r', encoding='utf-8') as conffile:
             return any(line.strip() in ACCESS_CONF_SNIPPETS
                        for line in conffile.readlines())
     except FileNotFoundError:
@@ -132,7 +129,7 @@ def get_apps_report():
         components = app_.get_components_of_type(Packages)
         packages = []
         for component in components:
-            packages += component.packages
+            packages += component.possible_packages
 
         if not packages:
             continue  # app has no managed packages
