@@ -20,8 +20,6 @@ _description = [
       'need to setup on the initial visit.'),
 ]
 
-app = None
-
 
 class ShaarliApp(app_module.App):
     """FreedomBox app for Shaarli."""
@@ -67,8 +65,7 @@ class ShaarliApp(app_module.App):
                                        **manifest.backup)
         self.add(backup_restore)
 
-
-def setup(helper, old_version=None):
-    """Install and configure the module."""
-    app.setup(old_version)
-    helper.call('post', app.enable)
+    def setup(self, old_version):
+        """Install and configure the app."""
+        super().setup(old_version)
+        self.enable()
