@@ -26,8 +26,6 @@ _description = [
       'using such connections.')
 ]
 
-app = None
-
 
 class SSHApp(app_module.App):
     """FreedomBox app for SSH."""
@@ -43,7 +41,8 @@ class SSHApp(app_module.App):
         info = app_module.Info(app_id=self.app_id, version=self._version,
                                is_essential=True,
                                name=_('Secure Shell (SSH) Server'),
-                               icon='fa-terminal', description=_description)
+                               icon='fa-terminal', description=_description,
+                               manual_page='SecureShell')
         self.add(info)
 
         menu_item = menu.Menu('menu-ssh', info.name, None, info.icon,
@@ -63,12 +62,11 @@ class SSHApp(app_module.App):
         backup_restore = BackupRestore('backup-restore-ssh', **manifest.backup)
         self.add(backup_restore)
 
-
-def setup(helper, old_version=None):
-    """Configure the module."""
-    app.setup(old_version)
-    actions.superuser_run('ssh', ['setup'])
-    helper.call('post', app.enable)
+    def setup(self, old_version):
+        """Install and configure the app."""
+        super().setup(old_version)
+        actions.superuser_run('ssh', ['setup'])
+        self.enable()
 
 
 def get_host_keys():
