@@ -9,7 +9,7 @@ from django.utils.translation import gettext_lazy as _
 
 from plinth import action_utils, actions
 from plinth import app as app_module
-from plinth import menu
+from plinth import cfg, menu
 from plinth.daemon import (Daemon, app_is_running, diagnose_netcat,
                            diagnose_port_listening)
 from plinth.modules.apache.components import diagnose_url
@@ -19,6 +19,7 @@ from plinth.modules.names.components import DomainType
 from plinth.modules.users.components import UsersAndGroups
 from plinth.package import Packages
 from plinth.signals import domain_added, domain_removed
+from plinth.utils import format_lazy
 
 from . import manifest, utils
 
@@ -28,11 +29,12 @@ _description = [
       'Project</a> website. For best protection when web surfing, the '
       'Tor Project recommends that you use the '
       '<a href="https://www.torproject.org/download/download-easy.html.en">'
-      'Tor Browser</a>.')
+      'Tor Browser</a>.'),
+    format_lazy(
+        _('A Tor SOCKS port is available on your {box_name} for internal '
+          'networks on TCP port 9050.'), box_name=_(cfg.box_name))
 ]
 
-app = None
-
 
 class TorApp(app_module.App):
     """FreedomBox app for Tor."""
@@ -93,7 +95,7 @@ class TorApp(app_module.App):
     def post_init(self):
         """Perform post initialization operations."""
         # Register hidden service name with Name Services module.
-        if (not app.needs_setup() and self.is_enabled()
+        if (not self.needs_setup() and self.is_enabled()
                 and app_is_running(self)):
             status = utils.get_status(initialized=False)
             hostname = status['hs_hostname']
@@ -151,19 +153,18 @@ class TorApp(app_module.App):
 
         return results
 
+    def setup(self, old_version):
+        """Install and configure the app."""
+        super().setup(old_version)
+        actions.superuser_run('tor',
+                              ['setup', '--old-version',
+                               str(old_version)])
+        if not old_version:
+            actions.superuser_run(
+                'tor', ['configure', '--apt-transport-tor', 'enable'])
 
-def setup(helper, old_version=None):
-    """Install and configure the module."""
-    app.setup(old_version)
-    helper.call(
-        'post', actions.superuser_run, 'tor',
-        ['setup', '--old-version', str(old_version)])
-    if not old_version:
-        helper.call('post', actions.superuser_run, 'tor',
-                    ['configure', '--apt-transport-tor', 'enable'])
-
-    helper.call('post', update_hidden_service_domain)
-    helper.call('post', app.enable)
+        update_hidden_service_domain()
+        self.enable()
 
 
 def update_hidden_service_domain(status=None):
