@@ -3,13 +3,11 @@
 FreedomBox app to configure Transmission server.
 """
 
-import json
-
+from django.urls import reverse_lazy
 from django.utils.translation import gettext_lazy as _
 
-from plinth import actions
 from plinth import app as app_module
-from plinth import frontpage, menu
+from plinth import cfg, frontpage, menu
 from plinth.daemon import Daemon
 from plinth.modules.apache.components import Webserver
 from plinth.modules.backups.components import BackupRestore
@@ -17,18 +15,33 @@ from plinth.modules.firewall.components import Firewall
 from plinth.modules.users import add_user_to_share_group
 from plinth.modules.users.components import UsersAndGroups
 from plinth.package import Packages
+from plinth.utils import format_lazy
 
-from . import manifest
+from . import manifest, privileged
 
 _description = [
     _('Transmission is a BitTorrent client with a web interface.'),
     _('BitTorrent is a peer-to-peer file sharing protocol. '
       'Note that BitTorrent is not anonymous.'),
     _('Please do not change the default port of the Transmission daemon.'),
+    format_lazy(
+        _('Compared to <a href="{deluge_url}">'
+          'Deluge</a>, Transmission is simpler and lightweight but is less '
+          'customizable.'), deluge_url=reverse_lazy('deluge:index')),
+    format_lazy(
+        _('It can be accessed by <a href="{users_url}">any user</a> on '
+          '{box_name} belonging to the bit-torrent group.'),
+        box_name=_(cfg.box_name), users_url=reverse_lazy('users:index')),
+    format_lazy(
+        _('<a href="{samba_url}">Samba</a> shares can be set as the '
+          'default download directory from the dropdown menu below.'),
+        samba_url=reverse_lazy('samba:index')),
+    format_lazy(
+        _('After a download has completed, you can also access your files '
+          'using the <a href="{sharing_url}">Sharing</a> app.'),
+        sharing_url=reverse_lazy('sharing:index'))
 ]
 
-app = None
-
 SYSTEM_USER = 'debian-transmission'
 
 
@@ -100,20 +113,17 @@ class TransmissionApp(app_module.App):
                                        **manifest.backup)
         self.add(backup_restore)
 
+    def setup(self, old_version):
+        """Install and configure the app."""
+        super().setup(old_version)
 
-def setup(helper, old_version=None):
-    """Install and configure the module."""
-    app.setup(old_version)
+        if old_version and old_version <= 3 and self.is_enabled():
+            self.get_component('firewall-transmission').enable()
 
-    if old_version and old_version <= 3 and app.is_enabled():
-        app.get_component('firewall-transmission').enable()
-
-    new_configuration = {
-        'rpc-whitelist-enabled': False,
-        'rpc-authentication-required': False
-    }
-    helper.call('post', actions.superuser_run, 'transmission',
-                ['merge-configuration'],
-                input=json.dumps(new_configuration).encode())
-    add_user_to_share_group(SYSTEM_USER, TransmissionApp.DAEMON)
-    helper.call('post', app.enable)
+        new_configuration = {
+            'rpc-whitelist-enabled': False,
+            'rpc-authentication-required': False
+        }
+        privileged.merge_configuration(new_configuration)
+        add_user_to_share_group(SYSTEM_USER, TransmissionApp.DAEMON)
+        self.enable()
