@@ -14,7 +14,7 @@ from plinth.modules.apache.components import Webserver
 from plinth.modules.backups.components import BackupRestore
 from plinth.modules.firewall.components import Firewall
 from plinth.modules.users.components import UsersAndGroups
-from plinth.package import Packages
+from plinth.package import Packages, install
 from plinth.utils import Version, format_lazy
 
 from . import manifest
@@ -24,16 +24,15 @@ _description = [
       'designed to allow reading news from any location, while feeling as '
       'close to a real desktop application as possible.'),
     format_lazy(
-        _('When enabled, Tiny Tiny RSS can be accessed by any '
-          '<a href="{users_url}">user with a {box_name} login</a>.'),
-        box_name=_(cfg.box_name), users_url=reverse_lazy('users:index')),
+        _('When enabled, Tiny Tiny RSS can be accessed by '
+          '<a href="{users_url}">any user</a> belonging to the '
+          'feed-reader group.'), box_name=_(cfg.box_name),
+        users_url=reverse_lazy('users:index')),
     format_lazy(
         _('When using a mobile or desktop application for Tiny Tiny RSS, use '
           'the URL <a href="/tt-rss-app/">/tt-rss-app</a> for connecting.'))
 ]
 
-app = None
-
 
 class TTRSSApp(app_module.App):
     """FreedomBox app for TT-RSS."""
@@ -106,6 +105,27 @@ class TTRSSApp(app_module.App):
             domain = next(names.get_available_tls_domains(), None)
             set_domain(domain)
 
+    def setup(self, old_version):
+        """Install and configure the app."""
+        actions.superuser_run('ttrss', ['pre-setup'])
+        super().setup(old_version)
+        actions.superuser_run('ttrss', ['setup'])
+        self.enable()
+
+    def force_upgrade(self, packages):
+        """Force update package to resolve conffile prompts."""
+        if 'tt-rss' not in packages:
+            return False
+
+        # Allow tt-rss any lower version to upgrade to 21.*
+        package = packages['tt-rss']
+        if Version(package['new_version']) > Version('22~'):
+            return False
+
+        install(['tt-rss'], force_configuration='new')
+        actions.superuser_run('ttrss', ['setup'])
+        return True
+
 
 class TTRSSBackupRestore(BackupRestore):
     """Component to backup/restore TT-RSS"""
@@ -121,29 +141,6 @@ class TTRSSBackupRestore(BackupRestore):
         actions.superuser_run('ttrss', ['restore-database'])
 
 
-def setup(helper, old_version=None):
-    """Install and configure the module."""
-    helper.call('pre', actions.superuser_run, 'ttrss', ['pre-setup'])
-    app.setup(old_version)
-    helper.call('post', actions.superuser_run, 'ttrss', ['setup'])
-    helper.call('post', app.enable)
-
-
-def force_upgrade(helper, packages):
-    """Force update package to resolve conffile prompts."""
-    if 'tt-rss' not in packages:
-        return False
-
-    # Allow tt-rss any lower version to upgrade to 21.*
-    package = packages['tt-rss']
-    if Version(package['new_version']) > Version('22~'):
-        return False
-
-    helper.install(['tt-rss'], force_configuration='new')
-    actions.superuser_run('ttrss', ['setup'])
-    return True
-
-
 def get_domain():
     """Read TLS domain from tt-rss config file."""
     return actions.superuser_run('ttrss', ['get-domain']).strip()
