@@ -24,12 +24,12 @@ from .forms import (CreateUserForm, FirstBootForm, UserChangePasswordForm,
                     UserUpdateForm)
 
 
-class ContextMixin(object):
+class ContextMixin:
     """Mixin to add 'title' to the template context."""
 
     def get_context_data(self, **kwargs):
         """Add self.title to template context."""
-        context = super(ContextMixin, self).get_context_data(**kwargs)
+        context = super().get_context_data(**kwargs)
         context['title'] = getattr(self, 'title', '')
         return context
 
@@ -45,7 +45,7 @@ class UserCreate(ContextMixin, SuccessMessageMixin, CreateView):
 
     def get_form_kwargs(self):
         """Make the request object available to the form."""
-        kwargs = super(UserCreate, self).get_form_kwargs()
+        kwargs = super().get_form_kwargs()
         kwargs['request'] = self.request
         return kwargs
 
@@ -62,7 +62,7 @@ class UserList(AppView, ContextMixin, django.views.generic.ListView):
     app_id = 'users'
 
     def get_context_data(self, *args, **kwargs):
-        context = super(UserList, self).get_context_data(*args, **kwargs)
+        context = super().get_context_data(*args, **kwargs)
         context['last_admin_user'] = get_last_admin_user()
         return context
 
@@ -86,14 +86,14 @@ class UserUpdate(ContextMixin, SuccessMessageMixin, UpdateView):
 
     def get_form_kwargs(self):
         """Make the request object available to the form."""
-        kwargs = super(UserUpdate, self).get_form_kwargs()
+        kwargs = super().get_form_kwargs()
         kwargs['request'] = self.request
         kwargs['username'] = self.object.username
         return kwargs
 
     def get_initial(self):
         """Return the data for initial form load."""
-        initial = super(UserUpdate, self).get_initial()
+        initial = super().get_initial()
         try:
             ssh_keys = actions.superuser_run(
                 'ssh', ['get-keys', '--username', self.object.username])
@@ -133,14 +133,16 @@ class UserDelete(ContextMixin, DeleteView):
     success_url = reverse_lazy('users:index')
     title = gettext_lazy('Delete User')
 
-    def delete(self, *args, **kwargs):
-        """Set the success message of deleting the user.
+    def __init__(self, *args, **kwargs):
+        super().__init__(*args, **kwargs)
 
-        The SuccessMessageMixin doesn't work with the DeleteView on Django1.7,
-        so set the success message manually here.
-        """
-        output = super(UserDelete, self).delete(*args, **kwargs)
+        # Avoid a warning with Django 4.0 that delete member should not be
+        # overridden. Remove this line and _delete() after Django 4.0 reaches
+        # Debian Stable.
+        self.delete = self._delete
 
+    def _delete_from_ldap(self):
+        """Remove user from LDAP and show a success/error message."""
         message = _('User {user} deleted.').format(user=self.kwargs['slug'])
         messages.success(self.request, message)
 
@@ -150,8 +152,26 @@ class UserDelete(ContextMixin, DeleteView):
         except ActionError:
             messages.error(self.request, _('Deleting LDAP user failed.'))
 
+    def _delete(self, *args, **kwargs):
+        """Set the success message of deleting the user.
+
+        The SuccessMessageMixin doesn't work with the DeleteView on Django1.7,
+        so set the success message manually here.
+        """
+        output = super().delete(*args, **kwargs)
+        self._delete_from_ldap()
         return output
 
+    def form_valid(self, form):
+        """Perform additional operations after delete.
+
+        Since Django 4.0, DeleteView inherits form_view and a call to delete()
+        is not made.
+        """
+        response = super().form_valid(form)  # NOQA, pylint: disable=no-member
+        self._delete_from_ldap()
+        return response
+
 
 class UserChangePassword(ContextMixin, SuccessMessageMixin, FormView):
     """View to change user password."""
@@ -170,7 +190,7 @@ class UserChangePassword(ContextMixin, SuccessMessageMixin, FormView):
 
     def get_form_kwargs(self):
         """Make the user object available to the form."""
-        kwargs = super(UserChangePassword, self).get_form_kwargs()
+        kwargs = super().get_form_kwargs()
         kwargs['request'] = self.request
         kwargs['user'] = User.objects.get(username=self.kwargs['slug'])
         return kwargs
@@ -189,7 +209,7 @@ class UserChangePassword(ContextMixin, SuccessMessageMixin, FormView):
         """
         form.save()
         update_session_auth_hash(self.request, form.user)
-        return super(UserChangePassword, self).form_valid(form)
+        return super().form_valid(form)
 
 
 class FirstBootView(django.views.generic.CreateView):
@@ -218,7 +238,7 @@ class FirstBootView(django.views.generic.CreateView):
 
     def get_form_kwargs(self):
         """Make request available to the form (to insert messages)"""
-        kwargs = super(FirstBootView, self).get_form_kwargs()
+        kwargs = super().get_form_kwargs()
         kwargs['request'] = self.request
         return kwargs
 
