@@ -40,15 +40,13 @@ _description = [
       'be installed and upgraded at your own risk.'),
 ]
 
-app = None
-
 
 class WordPressApp(app_module.App):
     """FreedomBox app for WordPress."""
 
     app_id = 'wordpress'
 
-    _version = 1
+    _version = 2
 
     def __init__(self):
         """Create components for the app."""
@@ -83,8 +81,6 @@ class WordPressApp(app_module.App):
                 'php',
                 # Optional, for performance
                 'php-imagick',
-                # Optional, to upload plugins/themes using SSH connection
-                'php-ssh2',
                 # Optional, for performance
                 'php-zip',
                 # WordPress only supports MySQL/MariaDB as DB
@@ -107,6 +103,13 @@ class WordPressApp(app_module.App):
                                                 **manifest.backup)
         self.add(backup_restore)
 
+    def setup(self, old_version):
+        """Install and configure the app."""
+        super().setup(old_version)
+        actions.superuser_run('wordpress', ['setup'])
+        if not old_version:
+            self.enable()
+
 
 class WordPressBackupRestore(BackupRestore):
     """Component to backup/restore WordPress."""
@@ -120,10 +123,3 @@ class WordPressBackupRestore(BackupRestore):
         """Restore database contents."""
         super().restore_post(packet)
         actions.superuser_run('wordpress', ['restore-database'])
-
-
-def setup(helper, old_version=None):
-    """Install and configure the module."""
-    app.setup(old_version)
-    helper.call('post', actions.superuser_run, 'wordpress', ['setup'])
-    helper.call('post', app.enable)
