@@ -8,8 +8,8 @@ import json
 import logging
 import pathlib
 import subprocess
-import sys
 import threading
+import time
 from typing import Optional, Union
 
 import apt.cache
@@ -17,12 +17,87 @@ from django.utils.translation import gettext as _
 from django.utils.translation import gettext_lazy
 
 from plinth import actions, app
-from plinth.errors import ActionError
+from plinth.errors import ActionError, MissingPackageError
 from plinth.utils import format_lazy
 
+from . import operation as operation_module
+from .errors import PackageNotInstalledError
+
 logger = logging.getLogger(__name__)
 
 
+class PackageExpression:
+
+    def possible(self) -> list[str]:
+        """Return the list of possible packages before resolving."""
+        raise NotImplementedError
+
+    def actual(self) -> str:
+        """Return the name of the package to install.
+
+        TODO: Also return version and suite to install from.
+        """
+        raise NotImplementedError
+
+
+class Package(PackageExpression):
+
+    def __init__(
+            self,
+            name,
+            optional: bool = False,
+            version: Optional[str] = None,  # ">=1.0,<2.0"
+            distribution: Optional[str] = None,  # Debian, Ubuntu
+            suite: Optional[str] = None,  # stable, testing
+            codename: Optional[str] = None,  # bullseye-backports
+            architecture: Optional[str] = None):  # arm64
+        self.name = name
+        self.optional = optional
+        self.version = version
+        self.distribution = distribution
+        self.suite = suite
+        self.codename = codename
+        self.architecture = architecture
+
+    def __repr__(self):
+        return self.name
+
+    def __or__(self, other):
+        return PackageOr(self, other)
+
+    def possible(self) -> list[str]:
+        return [self.name]
+
+    def actual(self) -> str:
+        cache = apt.Cache()
+        if self.name in cache:
+            # TODO: Also return version and suite to install from
+            return self.name
+
+        raise MissingPackageError(self.name)
+
+
+class PackageOr(PackageExpression):
+    """Specify that one of the two packages will be installed."""
+
+    def __init__(self, package1: PackageExpression,
+                 package2: PackageExpression):
+        self.package1 = package1
+        self.package2 = package2
+
+    def __repr__(self):
+        return self.package1.name + ' | ' + self.package2.name
+
+    def possible(self) -> list[str]:
+        return self.package1.possible() + self.package2.possible()
+
+    def actual(self) -> str:
+        try:
+            return self.package1.actual()
+        except MissingPackageError:
+            return self.package2.actual()
+
+
 class Packages(app.FollowerComponent):
     """Component to manage the packages of an app.
 
@@ -35,7 +110,8 @@ class Packages(app.FollowerComponent):
         IGNORE = 'ignore'  # Proceed as if there are no conflicts
         REMOVE = 'remove'  # Remove the packages before installing the app
 
-    def __init__(self, component_id: str, packages: list[str],
+    def __init__(self, component_id: str,
+                 packages: list[Union[str, PackageExpression]],
                  skip_recommends: bool = False,
                  conflicts: Optional[list[str]] = None,
                  conflicts_action: Optional[ConflictsAction] = None):
@@ -60,29 +136,59 @@ class Packages(app.FollowerComponent):
         super().__init__(component_id)
 
         self.component_id = component_id
-        self._packages = packages
+        self._packages: list[PackageExpression] = []
+        for package in packages:
+            if isinstance(package, str):
+                self._packages.append(Package(package))
+            else:
+                self._packages.append(package)
+
         self.skip_recommends = skip_recommends
         self.conflicts = conflicts
         self.conflicts_action = conflicts_action
 
     @property
-    def packages(self) -> list[str]:
-        """Return the list of packages managed by this component."""
+    def package_expressions(self) -> list[PackageExpression]:
+        """Return the list of managed packages as expressions."""
         return self._packages
 
+    @property
+    def possible_packages(self) -> list[str]:
+        """Return the list of possible packages before resolving."""
+        packages: list[str] = []
+        for package_expression in self.package_expressions:
+            packages.extend(package_expression.possible())
+
+        return packages
+
+    def get_actual_packages(self) -> list[str]:
+        """Return the computed list of packages to install.
+
+        Raise MissingPackageError if a required package is not available.
+        """
+        return [
+            package_expression.actual()
+            for package_expression in self.package_expressions
+        ]
+
     def setup(self, old_version):
         """Install the packages."""
-        # TODO: Drop the need for setup helper.
-        module_name = self.app.__module__
-        module = sys.modules[module_name]
-        helper = module.setup_helper
-        helper.install(self.packages, skip_recommends=self.skip_recommends)
+        install(self.get_actual_packages(),
+                skip_recommends=self.skip_recommends)
 
     def diagnose(self):
         """Run diagnostics and return results."""
         results = super().diagnose()
         cache = apt.Cache()
-        for package_name in self.packages:
+        for package_expression in self.package_expressions:
+            try:
+                package_name = package_expression.actual()
+            except MissingPackageError:
+                message = _('Package {expression} is not available for '
+                            'install').format(expression=package_expression)
+                results.append([message, 'failed'])
+                continue
+
             result = 'warning'
             latest_version = '?'
             if package_name in cache:
@@ -106,7 +212,7 @@ class Packages(app.FollowerComponent):
 
         return packages_installed(self.conflicts)
 
-    def has_unavailable_packages(self):
+    def has_unavailable_packages(self) -> Optional[bool]:
         """Return whether any of the packages are not available.
 
         Returns True if one or more of the packages is not available in the
@@ -121,9 +227,12 @@ class Packages(app.FollowerComponent):
             return None
 
         # List of all packages from all Package components
-        cache = apt.Cache()
-        return any(package for package in self.packages
-                   if package not in cache)
+        try:
+            self.get_actual_packages()
+        except MissingPackageError:
+            return True
+
+        return False
 
 
 class PackageException(Exception):
@@ -131,7 +240,7 @@ class PackageException(Exception):
 
     def __init__(self, error_string=None, error_details=None, *args, **kwargs):
         """Store apt-get error string and details."""
-        super(PackageException, self).__init__(*args, **kwargs)
+        super().__init__(*args, **kwargs)
 
         self.error_string = error_string
         self.error_details = error_details
@@ -142,15 +251,15 @@ class PackageException(Exception):
             .format(self.error_string, self.error_details)
 
 
-class Transaction(object):
+class Transaction:
     """Information about an ongoing transaction."""
 
-    def __init__(self, module_name, package_names):
+    def __init__(self, app_id, package_names):
         """Initialize transaction object.
 
         Set most values to None until they are sent as progress update.
         """
-        self.module_name = module_name
+        self.app_id = app_id
         self.package_names = package_names
 
         self._reset_status()
@@ -210,7 +319,7 @@ class Transaction(object):
                 extra_arguments.append('--force-missing-configuration')
 
             self._run_apt_command(['install'] + extra_arguments +
-                                  [self.module_name] + self.package_names)
+                                  [self.app_id] + self.package_names)
         except subprocess.CalledProcessError as exception:
             logger.exception('Error installing package: %s', exception)
             raise
@@ -277,6 +386,41 @@ class Transaction(object):
         self.percentage = int(float(parts[2]))
 
 
+def install(package_names, skip_recommends=False, force_configuration=None,
+            reinstall=False, force_missing_configuration=False):
+    """Install a set of packages marking progress."""
+    try:
+        operation = operation_module.Operation.get_operation()
+    except AttributeError:
+        raise RuntimeError(
+            'install() must be called from within an operation.')
+
+    if not operation.thread_data.get('allow_install', True):
+        # Raise error if packages are not already installed.
+        cache = apt.Cache()
+        for package_name in package_names:
+            if not cache[package_name].is_installed:
+                raise PackageNotInstalledError(package_name)
+
+        return
+
+    start_time = time.time()
+    while is_package_manager_busy():
+        if time.time() - start_time >= 24 * 3600:  # One day
+            raise PackageException(_('Timeout waiting for package manager'))
+
+        time.sleep(3)  # seconds
+
+    logger.info('Running install for app - %s, packages - %s',
+                operation.app_id, package_names)
+
+    from . import package
+    transaction = package.Transaction(operation.app_id, package_names)
+    operation.thread_data['transaction'] = transaction
+    transaction.install(skip_recommends, force_configuration, reinstall,
+                        force_missing_configuration)
+
+
 def is_package_manager_busy():
     """Return whether a package manager is running."""
     try:
