@@ -46,6 +46,7 @@ _site_url = {
     'jsxc': '/plinth/apps/jsxc/jsxc/',
     'cockpit': '/_cockpit/',
     'syncthing': '/syncthing/',
+    'rssbridge': '/rss-bridge/',
 }
 
 _sys_modules = [
@@ -203,6 +204,17 @@ def submit(browser, element=None, form_class=None, expected_url=None):
             browser.find_by_css('input[type=submit]').click()
 
 
+def set_app_form_value(browser, app_id, element_id, value):
+    """Change a value in the form and submit."""
+    nav_to_module(browser, app_id)
+    original_url = browser.url
+    browser.find_by_id(element_id).fill(value)
+    submit(browser, form_class='form-configuration')
+    # Check that there are no errors
+    assert browser.url == original_url
+    assert not browser.find_by_css('.alert-danger')
+
+
 def change_checkbox_status(browser, app_name, checkbox_id,
                            change_status_to='enabled'):
     """Change checkbox status."""
@@ -330,7 +342,7 @@ def install(browser, app_name):
     install_button_css = '.form-install input[type=submit]'
     while True:
         script = 'return (document.readyState == "complete") && ' \
-            '(!Boolean(document.querySelector(".installing")));'
+            '(!Boolean(document.querySelector(".app-operation")));'
         if not browser.execute_script(script):
             time.sleep(0.1)
         elif browser.is_element_present_by_css('.neterror'):
@@ -340,15 +352,10 @@ def install(browser, app_name):
         elif browser.is_element_present_by_css(install_button_css):
             install_button = browser.find_by_css(install_button_css).first
             if install_button['disabled']:
-                if not browser.find_by_name('refresh-packages'):
-                    # Package manager is busy, wait and refresh page
-                    time.sleep(1)
-                    browser.visit(browser.url)
-                else:
-                    # This app is not available in this distribution
-                    warnings.warn(
-                        f'App {app_name} is not available in distribution')
-                    pytest.skip('App not available in distribution')
+                # This app is not available in this distribution
+                warnings.warn(
+                    f'App {app_name} is not available in distribution')
+                pytest.skip('App not available in distribution')
             else:
                 install_button.click()
         else:
@@ -602,6 +609,7 @@ class BaseAppTests:
     has_web = True
     check_diagnostics = True
     diagnostics_delay = 0
+    disable_after_tests = True
 
     def assert_app_running(self, session_browser):
         """Assert that the app is running."""
@@ -627,7 +635,8 @@ class BaseAppTests:
         app_enable(session_browser, self.app_name)
         yield
         login(session_browser)
-        app_disable(session_browser, self.app_name)
+        if self.disable_after_tests:
+            app_disable(session_browser, self.app_name)
 
     def test_enable_disable(self, session_browser):
         """Test enabling and disabling the app."""
